@@ -141,7 +141,7 @@ plot_joint_scat <-
       geom_hline(
         yintercept = 0,
         colour = "grey60",
-        size = 0.2
+        linewidth = 0.2
       ),
       geom_point(shape = 16, alpha = 0.3),
       theme(legend.position = "none"),
@@ -226,7 +226,7 @@ plot_joint_scat <-
                )) +
         geom_hline(yintercept = c(pi, -pi),
                    colour = "black",
-                   size = 0.2) +
+                   linewidth = 0.2) +
         scale_y_continuous(breaks = seq(-1.5 * pi, 1.5 * pi, 0.25 * pi),
                            labels = c(
                              expression(
@@ -700,12 +700,12 @@ plot_joint_circ <- function(traj = NULL,
     geom_hline(
       yintercept = y_breaks[seq(2, length(y_breaks), 2)],
       colour = "darkgreen",
-      size = 0.2
+      linewidth = 0.2
     ),
     geom_hline(
       yintercept = y_breaks[seq(1, length(y_breaks), 2)],
       colour = "darkred",
-      size = 0.2
+      linewidth = 0.2
     ),
     #geom_vline(xintercept = x_breaks, colour = "grey90", size = 0.2),
     coord_polar(start = pi, clip = "off"),
@@ -727,7 +727,7 @@ plot_joint_circ <- function(traj = NULL,
     geom_hline(
       yintercept = tail(y_breaks, 1),
       colour = "grey30",
-      size = 0.2
+      linewidth = 0.2
     ),
 
     theme_bw(),
@@ -751,7 +751,7 @@ plot_joint_circ <- function(traj = NULL,
         yend = y_breaks[(length(y_breaks) - 1)]
       ),
       colour = "grey30",
-      size = 0.2
+      linewidth = 0.2
     ),
 
     geom_segment(
@@ -762,7 +762,7 @@ plot_joint_circ <- function(traj = NULL,
         yend = angle_label_pos$y
       ),
       colour = "grey30",
-      size = 0.2
+      linewidth = 0.2
     ),
 
     #hjust= and vjust= don't seem to work with coord_polar()
@@ -787,11 +787,12 @@ plot_joint_circ <- function(traj = NULL,
       data = angle_label_pos,
       aes(.data$x, .data$y),
       label = c(
-        expression(-0.75 * pi,-0.5 * pi,-0.25 * pi, 0,
-                   0.25 * pi, 0.5 * pi, 0.75 * pi, pi)
+        "-0.75 * pi", "-0.5 * pi", "-0.25 * pi", "0",
+        "0.25 * pi", "0.5 * pi", "0.75 * pi", "pi"
       ),
       size = 10 / 2.834646,
-      label.size = 0
+      label.size = 0,
+      parse = T
     )
   )
 
@@ -810,7 +811,7 @@ plot_joint_circ <- function(traj = NULL,
       data = marginal_angle_dens,
       aes(y = .data$y, x = .data$x),
       colour = "black",
-      size = 0.2
+      linewidth = 0.2
     ) +
     geom_ribbon(
       data = marginal_angle_dens,
@@ -972,7 +973,7 @@ plot_cop_scat <- function(traj = NULL,
 #' '\pkg{plotly}' package, or it can produce a heat map using functions from
 #' '\pkg{ggplot2}'.
 #'
-#' @param copula '\code{\linkS4class{cyl_copula}}' or a '\code{\linkS4class{Copula}}' object
+#' @param copula '\code{\linkS4class{cyl_copula}}' or a '\code{\link[copula:Copula-class]{Copula}}' object
 #' from the package '\pkg{copula}'.
 #' @param type \link[base]{character} string describing what is plotted,
 #' either \code{"pdf"} or \code{"cdf"}.
@@ -1540,13 +1541,13 @@ plot_cop_surf <- function(copula,
       geom_vline(
         xintercept = seq(0, 1, by = 0.125),
         colour = "grey60",
-        size = 0.8,
+        linewidth = 0.8,
         alpha = 0.25
       ) +
       geom_hline(
         yintercept = seq(0, 1, by = 0.125),
         colour = "grey60",
-        size = 0.8,
+        linewidth = 0.8,
         alpha = 0.25
       ) +
       scale_x_continuous(limits = c(0, 1), expand = c(0, 0)) +
@@ -1589,7 +1590,7 @@ plot_cop_surf <- function(copula,
 #' \code{"bottom"}
 #'
 #' @details You can either specify \code{traj} or the angels (\code{theta})
-#' and step lengths (code{x}).
+#' and step lengths (\code{x}).
 #' If entered "by hand", the named list describing the marginal linear distribution
 #' (for \code{marginal_lin}) must contain 2 entries:
 #' \enumerate{
@@ -2178,7 +2179,7 @@ make_plot <-
       geom_hline(
         yintercept = y_breaks[(length(y_breaks))],
         colour = "grey60",
-        size = 0.3 * expand
+        linewidth = 0.3 * expand
       ),
 
       theme_bw(),
@@ -2229,14 +2230,14 @@ make_plot <-
           yend = y_breaks[(length(y_breaks))]
         ),
         colour = "grey90",
-        size = 0.3 * expand
+        linewidth = 0.3 * expand
       ),
       #for position of axis labels
       geom_hline(
         yintercept = y_breaks[(length(y_breaks))] + 0.5 * expand,
         colour = "white",
         alpha = 0,
-        size = 0.3 * expand
+        linewidth = 0.3 * expand
       )
     )
 
@@ -2271,7 +2272,7 @@ make_plot <-
           xend = .data$xend,
           yend = .data$yend
         ),
-        size = 0.5 * expand
+        linewidth = 0.5 * expand
       ) +
       geom_segment(
         data = whiskers,
@@ -2281,7 +2282,7 @@ make_plot <-
           xend = .data$xend,
           yend = .data$yend
         ),
-        size = 0.4 * expand
+        linewidth = 0.4 * expand
       ) +
       geom_segment(
         data = endbars,
@@ -2291,7 +2292,7 @@ make_plot <-
           xend = .data$xend,
           yend = .data$yend
         ),
-        size = 0.4 * expand
+        linewidth = 0.4 * expand
       ) +
       geom_point(
         data = outliers,
@@ -2443,7 +2444,7 @@ plot_circ_hist <- function(theta, nbars = 20) {
         yend = .data$yend
       ),
       colour = "grey40",
-      size = 0.5
+      linewidth = 0.5
     ) +
     geom_segment(
       data = df_line_x_minor,
@@ -2454,7 +2455,7 @@ plot_circ_hist <- function(theta, nbars = 20) {
         yend = .data$yend
       ),
       colour = "grey60",
-      size = 0.2
+      linewidth = 0.2
     ) +
     geom_rect(
       data = df_rect,
@@ -2465,7 +2466,7 @@ plot_circ_hist <- function(theta, nbars = 20) {
         ymax = .data$ymax
       ),
       color = "black",
-      size = 0.5,
+      linewidth = 0.5,
       fill = "grey60"
     ) +
     coord_polar(start = pi) +
@@ -2480,19 +2481,20 @@ plot_circ_hist <- function(theta, nbars = 20) {
       ),
       aes(.data$x, .data$y),
       label = c(
-        expression(-0.75 * pi,-0.5 * pi,-0.25 * pi, 0,
-                   0.25 * pi, 0.5 * pi, 0.75 * pi, pi)
+        "-0.75 * pi", "-0.5 * pi", "-0.25 * pi", "0",
+        "0.25 * pi", "0.5 * pi", "0.75 * pi", "pi"
       ),
       size = 10 / 2.834646,
-      label.size = 0
+      label.size = 0,
+      parse = TRUE
     ) +
 
     geom_hline(yintercept = breaks[seq(2, length(breaks), 2)],
                colour = "darkgreen",
-               size = 0.2) +
+               linewidth = 0.2) +
     geom_hline(yintercept = breaks[seq(1, length(breaks), 2)],
                colour = "darkred",
-               size = 0.2) +
+               linewidth = 0.2) +
     geom_label(
       data = data.frame(x = rep(-0.95, length(breaks[seq(2, length(breaks), 2)])), y =
                           breaks[seq(2, length(breaks), 2)]),
